@@ -9,9 +9,12 @@ testthat::test_that("plotcurves function is consistent",{
   mod <- mtlr(formula,data)
   curves <- predict(mod)
   expect_warning(plotcurves(curves, index=  1:3, color = c("red","green")))
-
-  expect_equal_to_reference(plotcurves(curves), "1curve.rds")
-  expect_equal_to_reference(plotcurves(curves, color = "pink"), "1curve_colored.rds")
-  expect_equal_to_reference(plotcurves(curves, index = 1:20), "manycurves.rds")
-  expect_equal_to_reference(plotcurves(curves, xlim = c(0,20)), "curveshortx.rds")
+  oneCurve <- plotcurves(curves)
+  vdiffr::expect_doppelganger("oneCurve", oneCurve)
+  onePinkCurve <- plotcurves(curves)
+  vdiffr::expect_doppelganger("onePinkCurve", onePinkCurve)
+  manyCurves <- plotcurves(curves)
+  vdiffr::expect_doppelganger("manyCurves", manyCurves)
+  shortCurve <- plotcurves(curves)
+  vdiffr::expect_doppelganger("shortCurve", shortCurve)
 })
